summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--lisp/init-sane-defaults.el4
1 files changed, 2 insertions, 2 deletions
diff --git a/lisp/init-sane-defaults.el b/lisp/init-sane-defaults.el
index ef47af6..1bc02a5 100644
--- a/lisp/init-sane-defaults.el
+++ b/lisp/init-sane-defaults.el
@@ -14,8 +14,8 @@
;; disable audible bell
(setq ring-bell-function #'ignore)
-;; tweak scrolling when smooth scrolling is unavailable or disabled
-(when (not (bound-and-true-p mac-mouse-wheel-smooth-scroll))
+;; tweak scrolling unless smooth scrolling is enabled
+(unless (bound-and-true-p mac-mouse-wheel-smooth-scroll)
;; scroll one line at a time
(setq mouse-wheel-scroll-amount
'(1